## User OpenAI

This project is used for users to create a custom environment based on gymnasium. 

Currently, this project is used for LunarLander-v2 modification. 

## Installation

To install this library, use `pip install gym`. This library highly depends on Box2D and pygame, so make sure Box2D and pygame are successfully installed. 
